@@ -3,12 +3,12 @@ use std::fs;
 #[macro_use]
 mod helpers;
 mod discard;
+mod editor;
 mod log;
 mod push;
 mod quit;
 mod rebase;
 mod reset;
-mod scroll;
 mod stage;
 mod stash;
 mod unstage;
@@ -117,6 +117,47 @@ fn merge_conflict() {
     insta::assert_snapshot!(ctx.redact_buffer());
 }
 
+#[test]
+fn revert_conflict() {
+    let mut ctx = TestContext::setup_clone();
+    commit(ctx.dir.path(), "new-file", "hey");
+    commit(ctx.dir.path(), "new-file", "hi");
+
+    run(ctx.dir.path(), &["git", "revert", "HEAD~1"]);
+
+    ctx.init_state();
+    insta::assert_snapshot!(ctx.redact_buffer());
+}
+
+#[test]
+fn revert_abort() {
+    let ctx = TestContext::setup_clone();
+    commit(ctx.dir.path(), "new-file", "hey");
+    commit(ctx.dir.path(), "new-file", "hi");
+
+    run(ctx.dir.path(), &["git", "revert", "HEAD~1"]);
+
+    snapshot!(ctx, "Va");
+}
+
+#[test]
+fn revert_menu() {
+    let ctx = TestContext::setup_clone();
+    snapshot!(ctx, "llV");
+}
+
+#[test]
+fn revert_commit_prompt() {
+    let ctx = TestContext::setup_clone();
+    snapshot!(ctx, "llV-eV");
+}
+
+#[test]
+fn revert_commit() {
+    let ctx = TestContext::setup_clone();
+    snapshot!(ctx, "llV-eV<enter>");
+}
+
 #[test]
 fn moved_file() {
     let mut ctx = TestContext::setup_clone();
